# hipe4ml
![](https://github.com/hipe4ml/hipe4ml/workflows/Test%20package/badge.svg)
![](https://sonarcloud.io/api/project_badges/measure?project=hipe4ml_hipe4ml&metric=alert_status) 
![](https://img.shields.io/github/license/hipe4ml/hipe4ml)
[![](https://img.shields.io/pypi/pyversions/hipe4ml.svg?longCache=True)](https://pypi.org/project/hipe4ml/)
[![](https://img.shields.io/pypi/v/hipe4ml.svg?maxAge=3600)](https://pypi.org/project/hipe4ml/)

Minimal heavy ion physics environment for Machine Learning

# Contribute
## Run tests
If you have [Pylint](https://www.pylint.org/#install) and [Flake8](http://flake8.pycqa.org/en/latest/) on your development machine, you can run tests locally by using:
```bash
tests/run_tests.sh
```
in the repository base directory.
## Install in-development package
To install the in-development package, from the repository base directoy:
```bash
pip install -e .
```
